## This tool can be used to search to additional context for the past conversation.

### Note: Only use this tool if you think you dont have enough context to answer the user's question.

Use this tool to search relevant past messages from long-term memory.
Trigger this tool when the user refers to something that was discussed earlier but is not in the recent context window.
